@@ -246,12 +246,12 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
     QString unread;
 //     qDebug() << expanded << unreadCount << unreadRecursiveCount;
     if ( expanded && unreadCount > 0 )
-      unread = QString( QLatin1String( " (%1)" ) ).arg( unreadCount );
+      unread = QString::fromLatin1( " (%1)" ).arg( unreadCount );
     else if ( !expanded ) {
       if ( unreadCount != unreadRecursiveCount )
-        unread = QString( QLatin1String( " (%1 + %2)" ) ).arg( unreadCount ).arg( unreadRecursiveCount - unreadCount );
+        unread = QString::fromLatin1( " (%1 + %2)" ).arg( unreadCount ).arg( unreadRecursiveCount - unreadCount );
       else if ( unreadCount > 0 )
-        unread = QString( QLatin1String( " (%1)" ) ).arg( unreadCount );
+        unread = QString::fromLatin1( " (%1)" ).arg( unreadCount );
     }
 
     PainterStateSaver stateSaver( painter );
@@ -289,9 +289,9 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
       painter->setPen( unreadColor );
       painter->drawText( unreadRect, Qt::AlignLeft | Qt::AlignVCenter, unread );
     } else if ( option.decorationPosition == QStyleOptionViewItem::Top ) {
-      // draw over the icon
-      painter->setPen( unreadColor );
       if ( unreadCount > 0 ) {
+        // draw over the icon
+        painter->setPen( unreadColor );
         painter->drawText( iconRect, Qt::AlignCenter, QString::number( unreadCount ) );
       }
     }
@@ -322,6 +322,8 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
     return;
   }
 
+  if ( textColor.isValid() )
+    painter->setPen( textColor );
   painter->drawText( textRect, option4.displayAlignment | Qt::AlignVCenter, text );
 }
 
