@@ -63,8 +63,8 @@ class StandardMailActionManager::Private
     {
       mGenericManager = new StandardActionManager( actionCollection, parentWidget );
 
-      mParent->connect( mGenericManager, SIGNAL( actionStateUpdated() ),
-                        mParent, SIGNAL( actionStateUpdated() ) );
+      mParent->connect( mGenericManager, SIGNAL(actionStateUpdated()),
+                        mParent, SIGNAL(actionStateUpdated()) );
 
       mGenericManager->createAllActions();
 
@@ -88,7 +88,7 @@ class StandardMailActionManager::Private
 
       mGenericManager->action( Akonadi::StandardActionManager::SynchronizeCollections )->setWhatsThis(
         i18n( "Update the content of the selected folders." ) );
-      
+
       mGenericManager->setActionText( Akonadi::StandardActionManager::CutCollections,
                                       ki18np( "Cut Folder", "Cut %1 Folders" ) );
       mGenericManager->action( Akonadi::StandardActionManager::CutCollections )->setWhatsThis(
@@ -150,7 +150,7 @@ class StandardMailActionManager::Private
 
       mGenericManager->setContextText(
         StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageText,
-        i18n( "Could not create folder: %1" ) );
+        ki18n( "Could not create folder: %1" ) );
 
       mGenericManager->setContextText(
         StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageTitle,
@@ -167,7 +167,7 @@ class StandardMailActionManager::Private
 
       mGenericManager->setContextText(
         StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageText,
-        i18n( "Could not delete folder: %1" ) );
+        ki18n( "Could not delete folder: %1" ) );
 
       mGenericManager->setContextText(
         StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageTitle,
@@ -175,7 +175,7 @@ class StandardMailActionManager::Private
 
       mGenericManager->setContextText(
         StandardActionManager::CollectionProperties, StandardActionManager::DialogTitle,
-        i18nc( "@title:window", "Properties of Folder %1" ) );
+        ki18nc( "@title:window", "Properties of Folder %1" ) );
 
       mGenericManager->setContextText(
         StandardActionManager::DeleteItems, StandardActionManager::MessageBoxText,
@@ -188,7 +188,7 @@ class StandardMailActionManager::Private
 
       mGenericManager->setContextText(
         StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageText,
-        i18n( "Could not delete email: %1" ) );
+        ki18n( "Could not delete email: %1" ) );
 
       mGenericManager->setContextText(
         StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageTitle,
@@ -200,7 +200,7 @@ class StandardMailActionManager::Private
 
       mGenericManager->setContextText(
         StandardActionManager::CreateResource, StandardActionManager::ErrorMessageText,
-        i18n( "Could not create account: %1" ) );
+        ki18n( "Could not create account: %1" ) );
 
       mGenericManager->setContextText(
         StandardActionManager::CreateResource, StandardActionManager::ErrorMessageTitle,
@@ -217,7 +217,7 @@ class StandardMailActionManager::Private
 
       mGenericManager->setContextText(
         StandardActionManager::Paste, StandardActionManager::ErrorMessageText,
-        i18n( "Could not paste email: %1" ) );
+        ki18n( "Could not paste email: %1" ) );
 
       mGenericManager->setContextText(
         StandardActionManager::Paste, StandardActionManager::ErrorMessageTitle,
@@ -304,7 +304,7 @@ class StandardMailActionManager::Private
       bool canDeleteItem = true;
       bool isSystemFolder = false;
       if ( collectionIsSelected ) {
-        foreach( const Collection collection, selectedCollections )
+        foreach( const Collection &collection, selectedCollections )
         {
           if ( collection.isValid() ) {
             const Akonadi::CollectionStatistics stats = collection.statistics();
@@ -333,7 +333,7 @@ class StandardMailActionManager::Private
           mGenericManager->action( StandardActionManager::DeleteCollections )->setEnabled( false );
         }
       }
-        
+
       if ( mActions.contains( Akonadi::StandardMailActionManager::MoveToTrash ) )
         mActions.value( Akonadi::StandardMailActionManager::MoveToTrash )->setEnabled( itemIsSelected && canDeleteItem );
       if ( mActions.contains( Akonadi::StandardMailActionManager::RemoveDuplicates ) )
@@ -537,12 +537,12 @@ void StandardMailActionManager::setCollectionSelectionModel( QItemSelectionModel
   d->mCollectionSelectionModel = selectionModel;
   d->mGenericManager->setCollectionSelectionModel( selectionModel );
 
-  connect( selectionModel->model(), SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
-           SLOT( updateActions() ) );
-  connect( selectionModel->model(), SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
-           SLOT( updateActions() ) );
-  connect( selectionModel, SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
-           SLOT( updateActions() ) );
+  connect( selectionModel->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+           SLOT(updateActions()) );
+  connect( selectionModel->model(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+           SLOT(updateActions()) );
+  connect( selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+           SLOT(updateActions()) );
 
   d->updateActions();
 }
@@ -552,12 +552,12 @@ void StandardMailActionManager::setItemSelectionModel( QItemSelectionModel* sele
   d->mItemSelectionModel = selectionModel;
   d->mGenericManager->setItemSelectionModel( selectionModel );
 
-  connect( selectionModel, SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
-           SLOT( updateActions() ) );
+  connect( selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+           SLOT(updateActions()) );
 
   //to catch item modifications, listen to the model's dataChanged signal as well
-  connect( selectionModel->model(), SIGNAL( dataChanged( const QModelIndex&, const QModelIndex& ) ),
-           SLOT( updateActions() ) );
+  connect( selectionModel->model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+           SLOT(updateActions()) );
 
   d->updateActions();
 }
@@ -579,7 +579,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       d->mActions.insert( MarkMailAsRead, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_mark_as_read" ), action );
       action->setData( QByteArray( "R" ) );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMarkAs() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAs()) );
       break;
     case MarkMailAsUnread:
       action = new KAction( d->mParentWidget );
@@ -590,7 +590,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_mark_as_unread" ), action );
       action->setShortcut( Qt::CTRL+Qt::Key_U );
       action->setData( QByteArray( "U" ) );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMarkAs() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAs()) );
       break;
     case MarkMailAsImportant:
       action = new KAction( d->mParentWidget );
@@ -600,7 +600,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       d->mActions.insert( MarkMailAsImportant, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_mark_as_important" ), action );
       action->setData( QByteArray( "G" ) );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMarkAs() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAs()) );
       break;
     case MarkMailAsActionItem:
       action = new KAction( d->mParentWidget );
@@ -610,7 +610,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       d->mActions.insert( MarkMailAsActionItem, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_mark_as_action_item" ), action );
       action->setData( QByteArray( "K" ) );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMarkAs() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAs()) );
       break;
     case MarkAllMailAsRead:
       action = new KAction( d->mParentWidget );
@@ -620,7 +620,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       d->mActions.insert( MarkAllMailAsRead, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_mark_all_as_read" ), action );
       action->setData( QByteArray( "R" ) );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMarkAllAs() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()) );
       break;
     case MarkAllMailAsUnread:
       action = new KAction( d->mParentWidget );
@@ -630,7 +630,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       d->mActions.insert( MarkAllMailAsUnread, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_mark_all_as_unread" ), action );
       action->setData( QByteArray( "U" ) );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMarkAllAs() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()) );
       break;
     case MarkAllMailAsImportant:
       action = new KAction( d->mParentWidget );
@@ -640,7 +640,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       d->mActions.insert( MarkAllMailAsImportant, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_mark_all_as_important" ), action );
       action->setData( QByteArray( "G" ) );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMarkAllAs() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()) );
       break;
     case MarkAllMailAsActionItem:
       action = new KAction( d->mParentWidget );
@@ -650,7 +650,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       d->mActions.insert( MarkAllMailAsActionItem, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_mark_all_as_action_item" ), action );
       action->setData( QByteArray("K") );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMarkAllAs() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()) );
       break;
     case MoveToTrash:
       action = new KAction( d->mParentWidget );
@@ -660,7 +660,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       action->setWhatsThis( i18n( "Move message to trashcan" ) );
       d->mActions.insert( MoveToTrash, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_move_to_trash" ), action );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMoveToTrash() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMoveToTrash()) );
       break;
     case MoveAllToTrash:
       action = new KAction( d->mParentWidget );
@@ -668,7 +668,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       action->setText( i18n( "Move All to &Trash" ) );
       d->mActions.insert( MoveAllToTrash, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_move_all_to_trash" ), action );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotMoveAllToTrash() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMoveAllToTrash()) );
       break;
     case RemoveDuplicates:
       action = new KAction( d->mParentWidget );
@@ -676,21 +676,21 @@ KAction* StandardMailActionManager::createAction( Type type )
       action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_Asterisk ) );
       d->mActions.insert( RemoveDuplicates, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_remove_duplicates" ), action );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotRemoveDuplicates() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotRemoveDuplicates()) );
       break;
     case EmptyAllTrash:
       action = new KAction( d->mParentWidget );
       action->setText( i18n( "Empty All &Trash Folders" ) );
       d->mActions.insert( EmptyAllTrash, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_empty_all_trash" ), action );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotEmptyAllTrash() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotEmptyAllTrash()) );
       break;
     case EmptyTrash:
       action = new KAction( d->mParentWidget );
       action->setText( i18n( "E&mpty Trash" ) );
       d->mActions.insert( EmptyTrash, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_empty_trash" ), action );
-      connect( action, SIGNAL( triggered( bool ) ), this, SLOT( slotEmptyTrash() ) );
+      connect( action, SIGNAL(triggered(bool)), this, SLOT(slotEmptyTrash()) );
       break;
     default:
       Q_ASSERT( false ); // should never happen
@@ -782,4 +782,10 @@ void StandardMailActionManager::setCollectionPropertiesPageNames( const QStringL
   d->mGenericManager->setCollectionPropertiesPageNames( names );
 }
 
+Akonadi::StandardActionManager* StandardMailActionManager::standardActionManager() const
+{
+  return d->mGenericManager;
+}
+
+
 #include "standardmailactionmanager.moc"
