@@ -35,6 +35,7 @@
 #include "collectionfetchjob.h"
 #include "collectionfetchscope.h"
 #include "collectionmodifyjob.h"
+#include "invalidatecachejob_p.h"
 #include "itemfetchjob.h"
 #include "itemfetchscope.h"
 #include "itemmodifyjob.h"
@@ -133,6 +134,8 @@ class Akonadi::ResourceBasePrivate : public AgentBasePrivate
     void slotDeleteResourceCollectionDone( KJob *job );
     void slotCollectionDeletionDone( KJob *job );
 
+    void slotInvalidateCache( const Akonadi::Collection &collection );
+
     void slotPrepareItemRetrieval( const Akonadi::Item &item );
     void slotPrepareItemRetrievalResult( KJob* job );
 
@@ -148,21 +151,29 @@ class Akonadi::ResourceBasePrivate : public AgentBasePrivate
     void createItemSyncInstanceIfMissing()
     {
       Q_Q( ResourceBase );
-      Q_ASSERT_X( scheduler->currentTask().type == ResourceScheduler::SyncCollection,
-                  "createItemSyncInstance", "Calling items retrieval methods although no item retrieval is in progress" );
-      if ( !mItemSyncer ) {
-        mItemSyncer = new ItemSync( q->currentCollection() );
-        mItemSyncer->setTransactionMode( mItemTransactionMode );
-        if ( mItemSyncFetchScope )
-          mItemSyncer->setFetchScope( *mItemSyncFetchScope );
-        mItemSyncer->setProperty( "collection", QVariant::fromValue( q->currentCollection() ) );
-        connect( mItemSyncer, SIGNAL( percent( KJob*, unsigned long ) ), q, SLOT( slotPercent( KJob*, unsigned long ) ) );
-        connect( mItemSyncer, SIGNAL( result( KJob* ) ), q, SLOT( slotItemSyncDone( KJob* ) ) );
+      if ( scheduler->currentTask().type == ResourceScheduler::SyncCollection ) {
+        if ( !mItemSyncer ) {
+          mItemSyncer = new ItemSync( q->currentCollection() );
+          mItemSyncer->setTransactionMode( mItemTransactionMode );
+          if ( mItemSyncFetchScope ) {
+            mItemSyncer->setFetchScope( *mItemSyncFetchScope );
+          }
+          mItemSyncer->setProperty( "collection", QVariant::fromValue( q->currentCollection() ) );
+          connect( mItemSyncer, SIGNAL(percent(KJob*,ulong)), q, SLOT(slotPercent(KJob*,ulong)) );
+          connect( mItemSyncer, SIGNAL(result(KJob*)), q, SLOT(slotItemSyncDone(KJob*)) );
+        }
+        Q_ASSERT( mItemSyncer );
+      } else {
+        kWarning() << "Calling items retrieval methods although no item retrieval is in progress";
       }
-      Q_ASSERT( mItemSyncer );
     }
 
   public Q_SLOTS:
+    Q_SCRIPTABLE QString dumpToString()
+    {
+      return scheduler->dumpToString();
+    }
+
     Q_SCRIPTABLE void dump()
     {
       scheduler->dump();
@@ -288,39 +299,43 @@ ResourceBase::ResourceBase( const QString & id )
   d->scheduler = new ResourceScheduler( this );
 
   d->mChangeRecorder->setChangeRecordingEnabled( true );
-  connect( d->mChangeRecorder, SIGNAL( changesAdded() ),
-           d->scheduler, SLOT( scheduleChangeReplay() ) );
+  connect( d->mChangeRecorder, SIGNAL(changesAdded()),
+           d->scheduler, SLOT(scheduleChangeReplay()) );
 
   d->mChangeRecorder->setResourceMonitored( d->mId.toLatin1() );
   d->mChangeRecorder->fetchCollection( true );
 
-  connect( d->scheduler, SIGNAL( executeFullSync() ),
-           SLOT( retrieveCollections() ) );
-  connect( d->scheduler, SIGNAL( executeCollectionTreeSync() ),
-           SLOT( retrieveCollections() ) );
-  connect( d->scheduler, SIGNAL( executeCollectionSync( const Akonadi::Collection& ) ),
-           SLOT( slotSynchronizeCollection( const Akonadi::Collection& ) ) );
-  connect( d->scheduler, SIGNAL( executeCollectionAttributesSync( const Akonadi::Collection& ) ),
-           SLOT( slotSynchronizeCollectionAttributes(Akonadi::Collection)) );
-  connect( d->scheduler, SIGNAL( executeItemFetch( const Akonadi::Item&, const QSet<QByteArray>& ) ),
-           SLOT( slotPrepareItemRetrieval(Akonadi::Item)) );
-  connect( d->scheduler, SIGNAL( executeResourceCollectionDeletion() ),
-           SLOT( slotDeleteResourceCollection() ) );
-  connect( d->scheduler, SIGNAL( status( int, const QString& ) ),
-           SIGNAL( status( int, const QString& ) ) );
-  connect( d->scheduler, SIGNAL( executeChangeReplay() ),
-           d->mChangeRecorder, SLOT( replayNext() ) );
-  connect( d->scheduler, SIGNAL( fullSyncComplete() ), SIGNAL( synchronized() ) );
-  connect( d->mChangeRecorder, SIGNAL( nothingToReplay() ), d->scheduler, SLOT( taskDone() ) );
-  connect( d->mChangeRecorder, SIGNAL( collectionRemoved( const Akonadi::Collection& ) ),
-           d->scheduler, SLOT( collectionRemoved( const Akonadi::Collection& ) ) );
-  connect( this, SIGNAL( abortRequested() ), this, SLOT( slotAbortRequested() ) );
-  connect( this, SIGNAL( synchronized() ), d->scheduler, SLOT( taskDone() ) );
-  connect( this, SIGNAL( agentNameChanged( const QString& ) ),
-           this, SIGNAL( nameChanged( const QString& ) ) );
+  connect( d->scheduler, SIGNAL(executeFullSync()),
+           SLOT(retrieveCollections()) );
+  connect( d->scheduler, SIGNAL(executeCollectionTreeSync()),
+           SLOT(retrieveCollections()) );
+  connect( d->scheduler, SIGNAL(executeCollectionSync(Akonadi::Collection)),
+           SLOT(slotSynchronizeCollection(Akonadi::Collection)) );
+  connect( d->scheduler, SIGNAL(executeCollectionAttributesSync(Akonadi::Collection)),
+           SLOT(slotSynchronizeCollectionAttributes(Akonadi::Collection)) );
+  connect( d->scheduler, SIGNAL(executeItemFetch(Akonadi::Item,QSet<QByteArray>)),
+           SLOT(slotPrepareItemRetrieval(Akonadi::Item)) );
+  connect( d->scheduler, SIGNAL(executeResourceCollectionDeletion()),
+           SLOT(slotDeleteResourceCollection()) );
+  connect ( d->scheduler, SIGNAL(executeCacheInvalidation(Akonadi::Collection)),
+            SLOT(slotInvalidateCache(Akonadi::Collection)) );
+  connect( d->scheduler, SIGNAL(status(int,QString)),
+           SIGNAL(status(int,QString)) );
+  connect( d->scheduler, SIGNAL(executeChangeReplay()),
+           d->mChangeRecorder, SLOT(replayNext()) );
+  connect( d->scheduler, SIGNAL(fullSyncComplete()), SIGNAL(synchronized()) );
+  connect( d->scheduler, SIGNAL(collectionTreeSyncComplete()), SIGNAL(collectionTreeSynchronized()) );
+  connect( d->mChangeRecorder, SIGNAL(nothingToReplay()), d->scheduler, SLOT(taskDone()) );
+  connect( d->mChangeRecorder, SIGNAL(collectionRemoved(Akonadi::Collection)),
+           d->scheduler, SLOT(collectionRemoved(Akonadi::Collection)) );
+  connect( this, SIGNAL(abortRequested()), this, SLOT(slotAbortRequested()) );
+  connect( this, SIGNAL(synchronized()), d->scheduler, SLOT(taskDone()) );
+  connect( this, SIGNAL(collectionTreeSynchronized()), d->scheduler, SLOT(taskDone()) );
+  connect( this, SIGNAL(agentNameChanged(QString)),
+           this, SIGNAL(nameChanged(QString)) );
 
-  connect( &d->mProgressEmissionCompressor, SIGNAL( timeout() ),
-           this, SLOT( slotDelayedEmitProgress() ) );
+  connect( &d->mProgressEmissionCompressor, SIGNAL(timeout()),
+           this, SLOT(slotDelayedEmitProgress()) );
 
   d->scheduler->setOnline( d->mOnline );
   if ( !d->mChangeRecorder->isEmpty() )
@@ -330,7 +345,7 @@ ResourceBase::ResourceBase( const QString & id )
 
   new ResourceSelectJob( identifier() );
 
-  connect( d->mChangeRecorder->session(), SIGNAL( reconnected() ), SLOT( slotSessionReconnected() ) );
+  connect( d->mChangeRecorder->session(), SIGNAL(reconnected()), SLOT(slotSessionReconnected()) );
 }
 
 ResourceBase::~ResourceBase()
@@ -424,7 +439,7 @@ void ResourceBase::itemRetrieved( const Item &item )
   ItemModifyJob *job = new ItemModifyJob( i );
   // FIXME: remove once the item with which we call retrieveItem() has a revision number
   job->disableRevisionCheck();
-  connect( job, SIGNAL( result( KJob* ) ), SLOT( slotDeliveryDone( KJob* ) ) );
+  connect( job, SIGNAL(result(KJob*)), SLOT(slotDeliveryDone(KJob*)) );
 }
 
 void ResourceBasePrivate::slotDeliveryDone(KJob * job)
@@ -449,7 +464,7 @@ void ResourceBase::collectionAttributesRetrieved( const Collection &collection )
   }
 
   CollectionModifyJob *job = new CollectionModifyJob( collection );
-  connect( job, SIGNAL( result( KJob* ) ), SLOT( slotCollectionAttributesSyncDone( KJob* ) ) );
+  connect( job, SIGNAL(result(KJob*)), SLOT(slotCollectionAttributesSyncDone(KJob*)) );
 }
 
 void ResourceBasePrivate::slotCollectionAttributesSyncDone(KJob * job)
@@ -469,7 +484,7 @@ void ResourceBasePrivate::slotDeleteResourceCollection()
 
   CollectionFetchJob *job = new CollectionFetchJob( Collection::root(), CollectionFetchJob::FirstLevel );
   job->fetchScope().setResource( q->identifier() );
-  connect( job, SIGNAL( result( KJob* ) ), q, SLOT( slotDeleteResourceCollectionDone( KJob* ) ) );
+  connect( job, SIGNAL(result(KJob*)), q, SLOT(slotDeleteResourceCollectionDone(KJob*)) );
 }
 
 void ResourceBasePrivate::slotDeleteResourceCollectionDone( KJob *job )
@@ -483,7 +498,7 @@ void ResourceBasePrivate::slotDeleteResourceCollectionDone( KJob *job )
 
     if ( !fetchJob->collections().isEmpty() ) {
       CollectionDeleteJob *job = new CollectionDeleteJob( fetchJob->collections().first() );
-      connect( job, SIGNAL( result( KJob* ) ), q, SLOT( slotCollectionDeletionDone( KJob* ) ) );
+      connect( job, SIGNAL(result(KJob*)), q, SLOT(slotCollectionDeletionDone(KJob*)) );
     } else {
       // there is no resource collection, so just ignore the request
       scheduler->taskDone();
@@ -501,6 +516,13 @@ void ResourceBasePrivate::slotCollectionDeletionDone( KJob *job )
   scheduler->taskDone();
 }
 
+void ResourceBasePrivate::slotInvalidateCache( const Akonadi::Collection &collection )
+{
+  Q_Q( ResourceBase );
+  InvalidateCacheJob *job = new InvalidateCacheJob( collection, q );
+  connect( job, SIGNAL(result(KJob*)), scheduler, SLOT(taskDone()) );
+}
+
 void ResourceBase::changeCommitted( const Item& item )
 {
   Q_D( ResourceBase );
@@ -514,7 +536,7 @@ void ResourceBase::changeCommitted( const Item& item )
 void ResourceBase::changeCommitted( const Collection &collection )
 {
   CollectionModifyJob *job = new CollectionModifyJob( collection );
-  connect( job, SIGNAL( result( KJob* ) ), SLOT( changeCommittedResult( KJob* ) ) );
+  connect( job, SIGNAL(result(KJob*)), SLOT(changeCommittedResult(KJob*)) );
 }
 
 void ResourceBasePrivate::changeCommittedResult( KJob *job )
@@ -560,8 +582,8 @@ void ResourceBase::collectionsRetrieved( const Collection::List & collections )
   if ( !d->mCollectionSyncer ) {
     d->mCollectionSyncer = new CollectionSync( identifier() );
     d->mCollectionSyncer->setHierarchicalRemoteIds( d->mHierarchicalRid );
-    connect( d->mCollectionSyncer, SIGNAL( percent( KJob*, unsigned long ) ), SLOT( slotPercent( KJob*, unsigned long ) ) );
-    connect( d->mCollectionSyncer, SIGNAL( result( KJob* ) ), SLOT( slotCollectionSyncDone( KJob* ) ) );
+    connect( d->mCollectionSyncer, SIGNAL(percent(KJob*,ulong)), SLOT(slotPercent(KJob*,ulong)) );
+    connect( d->mCollectionSyncer, SIGNAL(result(KJob*)), SLOT(slotCollectionSyncDone(KJob*)) );
   }
   d->mCollectionSyncer->setRemoteCollections( collections );
 }
@@ -577,8 +599,8 @@ void ResourceBase::collectionsRetrievedIncremental( const Collection::List & cha
   if ( !d->mCollectionSyncer ) {
     d->mCollectionSyncer = new CollectionSync( identifier() );
     d->mCollectionSyncer->setHierarchicalRemoteIds( d->mHierarchicalRid );
-    connect( d->mCollectionSyncer, SIGNAL( percent( KJob*, unsigned long ) ), SLOT( slotPercent( KJob*, unsigned long ) ) );
-    connect( d->mCollectionSyncer, SIGNAL( result( KJob* ) ), SLOT( slotCollectionSyncDone( KJob* ) ) );
+    connect( d->mCollectionSyncer, SIGNAL(percent(KJob*,ulong)), SLOT(slotPercent(KJob*,ulong)) );
+    connect( d->mCollectionSyncer, SIGNAL(result(KJob*)), SLOT(slotCollectionSyncDone(KJob*)) );
   }
   d->mCollectionSyncer->setRemoteCollections( changedCollections, removedCollections );
 }
@@ -593,8 +615,8 @@ void ResourceBase::setCollectionStreamingEnabled( bool enable )
   if ( !d->mCollectionSyncer ) {
     d->mCollectionSyncer = new CollectionSync( identifier() );
     d->mCollectionSyncer->setHierarchicalRemoteIds( d->mHierarchicalRid );
-    connect( d->mCollectionSyncer, SIGNAL( percent( KJob*, unsigned long ) ), SLOT( slotPercent( KJob*, unsigned long ) ) );
-    connect( d->mCollectionSyncer, SIGNAL( result( KJob* ) ), SLOT( slotCollectionSyncDone( KJob* ) ) );
+    connect( d->mCollectionSyncer, SIGNAL(percent(KJob*,ulong)), SLOT(slotPercent(KJob*,ulong)) );
+    connect( d->mCollectionSyncer, SIGNAL(result(KJob*)), SLOT(slotCollectionSyncDone(KJob*)) );
   }
   d->mCollectionSyncer->setStreamingEnabled( enable );
 }
@@ -629,8 +651,10 @@ void ResourceBasePrivate::slotCollectionSyncDone( KJob * job )
       CollectionFetchJob *list = new CollectionFetchJob( Collection::root(), CollectionFetchJob::Recursive );
       list->setFetchScope( q->changeRecorder()->collectionFetchScope() );
       list->fetchScope().setResource( mId );
-      q->connect( list, SIGNAL( result( KJob* ) ), q, SLOT( slotLocalListDone( KJob* ) ) );
+      q->connect( list, SIGNAL(result(KJob*)), q, SLOT(slotLocalListDone(KJob*)) );
       return;
+    } else if ( scheduler->currentTask().type == ResourceScheduler::SyncCollectionTree ) {
+      scheduler->scheduleCollectionTreeSyncCompletion();
     }
   }
   scheduler->taskDone();
@@ -660,7 +684,7 @@ void ResourceBasePrivate::slotSynchronizeCollection( const Collection &col )
   contentTypes.removeAll( Collection::mimeType() );
   if ( !contentTypes.isEmpty() || (col.rights() & (Collection::CanLinkItem)) ) { // HACK to check for virtual collections
     if ( mAutomaticProgressReporting ) {
-      emit q->status( AgentBase::Running, i18nc( "@info:status", "Syncing collection '%1'", currentCollection.name() ) );
+      emit q->status( AgentBase::Running, i18nc( "@info:status", "Syncing folder '%1'", currentCollection.name() ) );
     }
     q->retrieveItems( currentCollection );
     return;
@@ -686,7 +710,7 @@ void ResourceBasePrivate::slotPrepareItemRetrieval( const Akonadi::Item &item )
   foreach ( const QByteArray &attribute, attributes )
     fetch->fetchScope().fetchAttribute( attribute );
 
-  q->connect( fetch, SIGNAL( result( KJob* ) ), SLOT( slotPrepareItemRetrievalResult( KJob* ) ) );
+  q->connect( fetch, SIGNAL(result(KJob*)), SLOT(slotPrepareItemRetrievalResult(KJob*)) );
 }
 
 void ResourceBasePrivate::slotPrepareItemRetrievalResult( KJob* job )
@@ -729,6 +753,12 @@ void ResourceBase::clearCache()
   d->scheduler->scheduleResourceCollectionDeletion();
 }
 
+void ResourceBase::invalidateCache(const Collection& collection)
+{
+  Q_D( ResourceBase );
+  d->scheduler->scheduleCacheInvalidation( collection );
+}
+
 Collection ResourceBase::currentCollection() const
 {
   Q_D( const ResourceBase );
@@ -809,7 +839,7 @@ void ResourceBase::synchronizeCollection( qint64 collectionId, bool recursive )
   job->setFetchScope( changeRecorder()->collectionFetchScope() );
   job->fetchScope().setResource( identifier() );
   job->setProperty( "recursive", recursive );
-  connect( job, SIGNAL( result( KJob* ) ), SLOT( slotCollectionListDone( KJob* ) ) );
+  connect( job, SIGNAL(result(KJob*)), SLOT(slotCollectionListDone(KJob*)) );
 }
 
 void ResourceBasePrivate::slotCollectionListDone( KJob *job )
@@ -834,7 +864,7 @@ void ResourceBase::synchronizeCollectionAttributes( qint64 collectionId )
   CollectionFetchJob* job = new CollectionFetchJob( Collection( collectionId ), CollectionFetchJob::Base );
   job->setFetchScope( changeRecorder()->collectionFetchScope() );
   job->fetchScope().setResource( identifier() );
-  connect( job, SIGNAL( result( KJob* ) ), SLOT( slotCollectionListForAttributesDone( KJob* ) ) );
+  connect( job, SIGNAL(result(KJob*)), SLOT(slotCollectionListForAttributesDone(KJob*)) );
 }
 
 void ResourceBasePrivate::slotCollectionListForAttributesDone( KJob *job )
