@@ -38,6 +38,11 @@
 #include "specialcollectionattribute_p.h"
 #include "collectionpropertiesdialog.h"
 #include "subscriptiondialog_p.h"
+#include "renamefavoritedialog.h"
+#include "trashjob.h"
+#include "trashrestorejob.h"
+#include "entitydeletedattribute.h"
+#include "recentcollectionaction_p.h"
 
 #include <KAction>
 #include <KActionCollection>
@@ -53,6 +58,7 @@
 #include <QtGui/QApplication>
 #include <QtGui/QClipboard>
 #include <QtGui/QItemSelectionModel>
+#include <QWeakPointer>
 
 #include <boost/static_assert.hpp>
 
@@ -63,6 +69,8 @@ using namespace Akonadi;
 enum ActionType
 {
   NormalAction,
+  ActionWithAlternative, //Normal action, but with an alternative state
+  ActionAlternative, //Alternative state of the ActionWithAlternative
   MenuAction,
   ToggleAction
 };
@@ -76,34 +84,44 @@ static const struct {
   const char* slot;
   ActionType actionType;
 } standardActionData[] = {
-  { "akonadi_collection_create", I18N_NOOP( "&New Folder..." ), I18N_NOOP( "New" ), "folder-new", 0, SLOT( slotCreateCollection() ), NormalAction },
-  { "akonadi_collection_copy", 0, 0, "edit-copy", 0, SLOT( slotCopyCollections() ), NormalAction },
-  { "akonadi_collection_delete", I18N_NOOP( "&Delete Folder" ), I18N_NOOP( "Delete" ), "edit-delete", 0, SLOT( slotDeleteCollection() ), NormalAction },
-  { "akonadi_collection_sync", I18N_NOOP( "&Synchronize Folder" ), I18N_NOOP( "Synchronize" ), "view-refresh", Qt::Key_F5, SLOT( slotSynchronizeCollection() ), NormalAction },
-  { "akonadi_collection_properties", I18N_NOOP( "Folder &Properties" ), I18N_NOOP( "Properties" ), "configure", 0, SLOT( slotCollectionProperties() ), NormalAction },
-  { "akonadi_item_copy", 0, 0, "edit-copy", 0, SLOT( slotCopyItems() ), NormalAction },
-  { "akonadi_paste", I18N_NOOP( "&Paste" ), I18N_NOOP( "Paste" ), "edit-paste", Qt::CTRL + Qt::Key_V, SLOT( slotPaste() ), NormalAction },
-  { "akonadi_item_delete", 0, 0, "edit-delete", Qt::Key_Delete, SLOT( slotDeleteItems() ), NormalAction },
-  { "akonadi_manage_local_subscriptions", I18N_NOOP( "Manage Local &Subscriptions..." ), I18N_NOOP( "Manage Local Subscriptions" ), 0, 0, SLOT( slotLocalSubscription() ), NormalAction },
-  { "akonadi_collection_add_to_favorites", I18N_NOOP( "Add to Favorite Folders" ), I18N_NOOP( "Add to Favorite" ), "bookmark-new", 0, SLOT( slotAddToFavorites() ), NormalAction },
-  { "akonadi_collection_remove_from_favorites", I18N_NOOP( "Remove from Favorite Folders" ), I18N_NOOP( "Remove from Favorite" ), "edit-delete", 0, SLOT( slotRemoveFromFavorites() ), NormalAction },
-  { "akonadi_collection_rename_favorite", I18N_NOOP( "Rename Favorite..." ), I18N_NOOP( "Rename" ), "edit-rename", 0, SLOT( slotRenameFavorite() ), NormalAction },
-  { "akonadi_collection_copy_to_menu", I18N_NOOP( "Copy Folder To..." ), I18N_NOOP( "Copy To" ), "edit-copy", 0, SLOT( slotCopyCollectionTo( QAction* ) ), MenuAction },
-  { "akonadi_item_copy_to_menu", I18N_NOOP( "Copy Item To..." ), I18N_NOOP( "Copy To" ), "edit-copy", 0, SLOT( slotCopyItemTo( QAction* ) ), MenuAction },
-  { "akonadi_item_move_to_menu", I18N_NOOP( "Move Item To..." ), I18N_NOOP( "Move To" ), "go-jump", 0, SLOT( slotMoveItemTo( QAction* ) ), MenuAction },
-  { "akonadi_collection_move_to_menu", I18N_NOOP( "Move Folder To..." ), I18N_NOOP( "Move To" ), "go-jump", 0, SLOT( slotMoveCollectionTo( QAction* ) ), MenuAction },
-  { "akonadi_item_cut", I18N_NOOP( "&Cut Item" ), I18N_NOOP( "Cut" ), "edit-cut", Qt::CTRL + Qt::Key_X, SLOT( slotCutItems() ), NormalAction },
-  { "akonadi_collection_cut", I18N_NOOP( "&Cut Folder" ), I18N_NOOP( "Cut" ), "edit-cut", Qt::CTRL + Qt::Key_X, SLOT( slotCutCollections() ), NormalAction },
-  { "akonadi_resource_create", I18N_NOOP( "Create Resource" ), 0, "folder-new", 0, SLOT( slotCreateResource() ), NormalAction },
-  { "akonadi_resource_delete", I18N_NOOP( "Delete Resource" ), 0, "edit-delete", 0, SLOT( slotDeleteResource() ), NormalAction },
-  { "akonadi_resource_properties", I18N_NOOP( "&Resource Properties" ), I18N_NOOP( "Properties" ), "configure", 0, SLOT( slotResourceProperties() ), NormalAction },
-  { "akonadi_resource_synchronize", I18N_NOOP( "Synchronize Resource" ), I18N_NOOP( "Synchronize" ), "view-refresh", 0, SLOT( slotSynchronizeResource() ), NormalAction },
-  { "akonadi_work_offline", I18N_NOOP( "Work Offline" ), 0, "user-offline", 0, SLOT( slotToggleWorkOffline(bool) ), ToggleAction },
-  { "akonadi_collection_copy_to_dialog", I18N_NOOP( "Copy Folder To..." ), I18N_NOOP( "Copy To" ), "edit-copy", 0, SLOT( slotCopyCollectionTo() ), NormalAction },
-  { "akonadi_collection_move_to_dialog", I18N_NOOP( "Move Folder To..." ), I18N_NOOP( "Move To" ), "go-jump", 0, SLOT( slotMoveCollectionTo() ), NormalAction },
-  { "akonadi_item_copy_to_dialog", I18N_NOOP( "Copy Item To..." ), I18N_NOOP( "Copy To" ), "edit-copy", 0, SLOT( slotCopyItemTo() ), NormalAction },
-  { "akonadi_item_move_to_dialog", I18N_NOOP( "Move Item To..." ), I18N_NOOP( "Move To" ), "go-jump", 0, SLOT( slotMoveItemTo() ), NormalAction },
-  { "akonadi_collection_sync_recursive", I18N_NOOP( "&Synchronize Folder Recursively" ), I18N_NOOP( "Synchronize Recursively" ), "view-refresh", Qt::CTRL + Qt::Key_F5, SLOT( slotSynchronizeCollectionRecursive() ), NormalAction }
+  { "akonadi_collection_create", I18N_NOOP( "&New Folder..." ), I18N_NOOP( "New" ), "folder-new", 0, SLOT(slotCreateCollection()), NormalAction },
+  { "akonadi_collection_copy", 0, 0, "edit-copy", 0, SLOT(slotCopyCollections()), NormalAction },
+  { "akonadi_collection_delete", I18N_NOOP( "&Delete Folder" ), I18N_NOOP( "Delete" ), "edit-delete", 0, SLOT(slotDeleteCollection()), NormalAction },
+  { "akonadi_collection_sync", I18N_NOOP( "&Synchronize Folder" ), I18N_NOOP( "Synchronize" ), "view-refresh", Qt::Key_F5, SLOT(slotSynchronizeCollection()), NormalAction },
+  { "akonadi_collection_properties", I18N_NOOP( "Folder &Properties" ), I18N_NOOP( "Properties" ), "configure", 0, SLOT(slotCollectionProperties()), NormalAction },
+  { "akonadi_item_copy", 0, 0, "edit-copy", 0, SLOT(slotCopyItems()), NormalAction },
+  { "akonadi_paste", I18N_NOOP( "&Paste" ), I18N_NOOP( "Paste" ), "edit-paste", Qt::CTRL + Qt::Key_V, SLOT(slotPaste()), NormalAction },
+  { "akonadi_item_delete", 0, 0, "edit-delete", Qt::Key_Delete, SLOT(slotDeleteItems()), NormalAction },
+  { "akonadi_manage_local_subscriptions", I18N_NOOP( "Manage Local &Subscriptions..." ), I18N_NOOP( "Manage Local Subscriptions" ), "folder-bookmarks", 0, SLOT(slotLocalSubscription()), NormalAction },
+  { "akonadi_collection_add_to_favorites", I18N_NOOP( "Add to Favorite Folders" ), I18N_NOOP( "Add to Favorite" ), "bookmark-new", 0, SLOT(slotAddToFavorites()), NormalAction },
+  { "akonadi_collection_remove_from_favorites", I18N_NOOP( "Remove from Favorite Folders" ), I18N_NOOP( "Remove from Favorite" ), "edit-delete", 0, SLOT(slotRemoveFromFavorites()), NormalAction },
+  { "akonadi_collection_rename_favorite", I18N_NOOP( "Rename Favorite..." ), I18N_NOOP( "Rename" ), "edit-rename", 0, SLOT(slotRenameFavorite()), NormalAction },
+  { "akonadi_collection_copy_to_menu", I18N_NOOP( "Copy Folder To..." ), I18N_NOOP( "Copy To" ), "edit-copy", 0, SLOT(slotCopyCollectionTo(QAction*)), MenuAction },
+  { "akonadi_item_copy_to_menu", I18N_NOOP( "Copy Item To..." ), I18N_NOOP( "Copy To" ), "edit-copy", 0, SLOT(slotCopyItemTo(QAction*)), MenuAction },
+  { "akonadi_item_move_to_menu", I18N_NOOP( "Move Item To..." ), I18N_NOOP( "Move To" ), "go-jump", 0, SLOT(slotMoveItemTo(QAction*)), MenuAction },
+  { "akonadi_collection_move_to_menu", I18N_NOOP( "Move Folder To..." ), I18N_NOOP( "Move To" ), "go-jump", 0, SLOT(slotMoveCollectionTo(QAction*)), MenuAction },
+  { "akonadi_item_cut", I18N_NOOP( "&Cut Item" ), I18N_NOOP( "Cut" ), "edit-cut", Qt::CTRL + Qt::Key_X, SLOT(slotCutItems()), NormalAction },
+  { "akonadi_collection_cut", I18N_NOOP( "&Cut Folder" ), I18N_NOOP( "Cut" ), "edit-cut", Qt::CTRL + Qt::Key_X, SLOT(slotCutCollections()), NormalAction },
+  { "akonadi_resource_create", I18N_NOOP( "Create Resource" ), 0, "folder-new", 0, SLOT(slotCreateResource()), NormalAction },
+  { "akonadi_resource_delete", I18N_NOOP( "Delete Resource" ), 0, "edit-delete", 0, SLOT(slotDeleteResource()), NormalAction },
+  { "akonadi_resource_properties", I18N_NOOP( "&Resource Properties" ), I18N_NOOP( "Properties" ), "configure", 0, SLOT(slotResourceProperties()), NormalAction },
+  { "akonadi_resource_synchronize", I18N_NOOP( "Synchronize Resource" ), I18N_NOOP( "Synchronize" ), "view-refresh", 0, SLOT(slotSynchronizeResource()), NormalAction },
+  { "akonadi_work_offline", I18N_NOOP( "Work Offline" ), 0, "user-offline", 0, SLOT(slotToggleWorkOffline(bool)), ToggleAction },
+  { "akonadi_collection_copy_to_dialog", I18N_NOOP( "Copy Folder To..." ), I18N_NOOP( "Copy To" ), "edit-copy", 0, SLOT(slotCopyCollectionTo()), NormalAction },
+  { "akonadi_collection_move_to_dialog", I18N_NOOP( "Move Folder To..." ), I18N_NOOP( "Move To" ), "go-jump", 0, SLOT(slotMoveCollectionTo()), NormalAction },
+  { "akonadi_item_copy_to_dialog", I18N_NOOP( "Copy Item To..." ), I18N_NOOP( "Copy To" ), "edit-copy", 0, SLOT(slotCopyItemTo()), NormalAction },
+  { "akonadi_item_move_to_dialog", I18N_NOOP( "Move Item To..." ), I18N_NOOP( "Move To" ), "go-jump", 0, SLOT(slotMoveItemTo()), NormalAction },
+  { "akonadi_collection_sync_recursive", I18N_NOOP( "&Synchronize Folder Recursively" ), I18N_NOOP( "Synchronize Recursively" ), "view-refresh", Qt::CTRL + Qt::Key_F5, SLOT(slotSynchronizeCollectionRecursive()), NormalAction },
+  { "akonadi_move_collection_to_trash", I18N_NOOP( "&Move Folder To Trash" ), I18N_NOOP( "Move Folder To Trash" ), "user-trash", 0, SLOT(slotMoveCollectionToTrash()), NormalAction },
+  { "akonadi_move_item_to_trash", I18N_NOOP( "&Move Item To Trash" ), I18N_NOOP( "Move Item To Trash" ), "user-trash", 0, SLOT(slotMoveItemToTrash()), NormalAction },
+  { "akonadi_restore_collection_from_trash", I18N_NOOP( "&Restore Folder From Trash" ), I18N_NOOP( "Restore Folder From Trash" ), "view-refresh", 0, SLOT(slotRestoreCollectionFromTrash()), NormalAction },
+  { "akonadi_restore_item_from_trash", I18N_NOOP( "&Restore Item From Trash" ), I18N_NOOP( "Restore Item From Trash" ), "view-refresh", 0, SLOT(slotRestoreItemFromTrash()), NormalAction },
+  { "akonadi_collection_trash_restore", I18N_NOOP( "&Restore Folder From Trash" ), I18N_NOOP( "Restore Folder From Trash" ), "user-trash", 0, SLOT(slotTrashRestoreCollection()), ActionWithAlternative },
+  { 0, I18N_NOOP( "&Restore Collection From Trash" ), I18N_NOOP( "Restore Collection From Trash" ), "view-refresh", 0, 0, ActionAlternative },
+  { "akonadi_item_trash_restore", I18N_NOOP( "&Restore Item From Trash" ), I18N_NOOP( "Restore Item From Trash" ), "user-trash", 0, SLOT(slotTrashRestoreItem()), ActionWithAlternative },
+  { 0, I18N_NOOP( "&Restore Item From Trash" ), I18N_NOOP( "Restore Item From Trash" ), "view-refresh", 0, 0, ActionAlternative },
+  { "akonadi_collection_sync_favorite_folders", I18N_NOOP( "&Synchronize Favorite Folders" ), I18N_NOOP( "Synchronize Favorite Folders" ), "view-refresh", Qt::CTRL+Qt::SHIFT+Qt::Key_L , SLOT(slotSynchronizeFavoriteCollections()), NormalAction }
+
 };
 static const int numStandardActionData = sizeof standardActionData / sizeof *standardActionData;
 
@@ -175,6 +193,7 @@ class StandardActionManager::Private
       pluralLabels.insert( StandardActionManager::SynchronizeResources,
                            ki18np( "&Synchronize Resource", "&Synchronize %1 Resources" ) );
 
+
       pluralIconLabels.insert( StandardActionManager::CopyCollections,
                            ki18np( "Copy Folder", "Copy %1 Folders" ) );
       pluralIconLabels.insert( StandardActionManager::CopyItems,
@@ -199,7 +218,7 @@ class StandardActionManager::Private
       setContextText( StandardActionManager::CreateCollection, StandardActionManager::DialogText,
                       i18nc( "@label:textbox name of a thing", "Name" ) );
       setContextText( StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageText,
-                      i18n( "Could not create folder: %1" ) );
+                      ki18n( "Could not create folder: %1" ) );
       setContextText( StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageTitle,
                       i18n( "Folder creation failed" ) );
 
@@ -209,12 +228,12 @@ class StandardActionManager::Private
       setContextText( StandardActionManager::DeleteCollections, StandardActionManager::MessageBoxTitle,
                       ki18ncp( "@title:window", "Delete folder?", "Delete folders?" ) );
       setContextText( StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageText,
-                      i18n( "Could not delete folder: %1" ) );
+                      ki18n( "Could not delete folder: %1" ) );
       setContextText( StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageTitle,
                       i18n( "Folder deletion failed" ) );
 
       setContextText( StandardActionManager::CollectionProperties, StandardActionManager::DialogTitle,
-                      i18nc( "@title:window", "Properties of Folder %1" ) );
+                      ki18nc( "@title:window", "Properties of Folder %1" ) );
 
       setContextText( StandardActionManager::DeleteItems, StandardActionManager::MessageBoxText,
                       ki18np( "Do you really want to delete the selected item?",
@@ -222,7 +241,7 @@ class StandardActionManager::Private
       setContextText( StandardActionManager::DeleteItems, StandardActionManager::MessageBoxTitle,
                       ki18ncp( "@title:window", "Delete item?", "Delete items?" ) );
       setContextText( StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageText,
-                      i18n( "Could not delete item: %1" ) );
+                      ki18n( "Could not delete item: %1" ) );
       setContextText( StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageTitle,
                       i18n( "Item deletion failed" ) );
 
@@ -234,7 +253,7 @@ class StandardActionManager::Private
       setContextText( StandardActionManager::CreateResource, StandardActionManager::DialogTitle,
                       i18nc( "@title:window", "New Resource" ) );
       setContextText( StandardActionManager::CreateResource, StandardActionManager::ErrorMessageText,
-                      i18n( "Could not create resource: %1" ) );
+                      ki18n( "Could not create resource: %1" ) );
       setContextText( StandardActionManager::CreateResource, StandardActionManager::ErrorMessageTitle,
                       i18n( "Resource creation failed" ) );
 
@@ -245,7 +264,7 @@ class StandardActionManager::Private
                       ki18ncp( "@title:window", "Delete Resource?", "Delete Resources?" ) );
 
       setContextText( StandardActionManager::Paste, StandardActionManager::ErrorMessageText,
-                      i18n( "Could not paste data: %1" ) );
+                      ki18n( "Could not paste data: %1" ) );
       setContextText( StandardActionManager::Paste, StandardActionManager::ErrorMessageTitle,
                       i18n( "Paste failed" ) );
 
@@ -275,8 +294,8 @@ class StandardActionManager::Private
         menu = new KMenu();
 
         menu->setProperty( "actionType", static_cast<int>( type ) );
-        q->connect( menu, SIGNAL( aboutToShow() ), SLOT( aboutToShowMenu() ) );
-        q->connect( menu, SIGNAL( triggered( QAction* ) ), standardActionData[ type ].slot );
+        q->connect( menu, SIGNAL(aboutToShow()), SLOT(aboutToShowMenu()) );
+        q->connect( menu, SIGNAL(triggered(QAction*)), standardActionData[ type ].slot );
         actionMenu->setMenu( menu );
       }
     }
@@ -291,14 +310,81 @@ class StandardActionManager::Private
         return;
       const StandardActionManager::Type type = static_cast<StandardActionManager::Type>( menu->property( "actionType" ).toInt() );
 
+      QWeakPointer<RecentCollectionAction> recentCollection = new RecentCollectionAction( collectionSelectionModel->model(), menu );
+      mRecentCollectionsMenu.insert( type, recentCollection );
       const QSet<QString> mimeTypes = mimeTypesOfSelection( type );
-      fillFoldersMenu( mimeTypes, 
+      fillFoldersMenu( mimeTypes,
                        type,
                        menu,
                        collectionSelectionModel->model(),
                        QModelIndex() );
     }
 
+    void createActionFolderMenu(QMenu *menu, StandardActionManager::Type type)
+    {
+      if ( type == CopyCollectionToMenu ||
+           type == CopyItemToMenu ||
+           type == MoveItemToMenu ||
+           type ==MoveCollectionToMenu )
+      {
+
+        QWeakPointer<RecentCollectionAction> recentCollection = new RecentCollectionAction( collectionSelectionModel->model(), menu );
+        const QSet<QString> mimeTypes = mimeTypesOfSelection( type );
+        fillFoldersMenu( mimeTypes,
+                         type,
+                         menu,
+                         collectionSelectionModel->model(),
+                         QModelIndex() );
+      }
+    }
+
+
+    void updateAlternatingAction( int type )
+    {
+      updateAlternatingAction( static_cast<StandardActionManager::Type>( type ) );
+    }
+
+    void updateAlternatingAction( StandardActionManager::Type type )
+    {
+      Q_ASSERT( type < StandardActionManager::LastType );
+      if (!actions[type]) {
+        return;
+      }
+
+      /*
+       * The same action is stored at the ActionWithAlternative indexes as well as the corresponding ActionAlternative indexes in the actions array.
+       * The following simply changes the standardActionData
+       */
+      if ( ( standardActionData[type].actionType == ActionWithAlternative ) || ( standardActionData[type].actionType == ActionAlternative ) ) {
+        actions[type]->setText( i18n ( standardActionData[type].label ) );
+        actions[type]->setIcon( KIcon( QString::fromLatin1( standardActionData[type].icon ) ) );
+
+        if ( pluralLabels.contains( type ) && !pluralLabels.value( type ).isEmpty() )
+          actions[type]->setText( pluralLabels.value( type ).subs( 1 ).toString() );
+        else if ( standardActionData[type].label )
+          actions[type]->setText( i18n( standardActionData[type].label ) );
+
+        if ( pluralIconLabels.contains( type ) && !pluralIconLabels.value( type ).isEmpty() )
+          actions[type]->setIconText( pluralIconLabels.value( type ).subs( 1 ).toString() );
+        else if ( standardActionData[type].iconLabel )
+          actions[type]->setIconText( i18n( standardActionData[type].iconLabel ) );
+
+        if ( standardActionData[type].icon )
+          actions[type]->setIcon( KIcon( QString::fromLatin1( standardActionData[type].icon ) ) );
+
+        //actions[type]->setShortcut( standardActionData[type].shortcut );
+
+        /*if ( standardActionData[type].slot ) {
+          switch ( standardActionData[type].actionType ) {
+            case NormalAction:
+            case ActionWithAlternative:
+              connect( action, SIGNAL(triggered()), standardActionData[type].slot );
+              break;
+          }
+        }*/
+      }
+    }
+
     void updatePluralLabel( int type, int count )
     {
       updatePluralLabel( static_cast<StandardActionManager::Type>( type ), count );
@@ -459,6 +545,14 @@ class StandardActionManager::Private
       if ( name.isEmpty() )
         return;
 
+      if ( name.contains( QLatin1Char( '/' ) ) ) {
+        KMessageBox::error( parentWidget,
+                            i18n( "We can not add \"/\" in folder name." ),
+                            i18n( "Create new folder error" ) );
+
+        return;
+      }
+
       Collection collection;
       collection.setName( name );
       collection.setParentCollection( parentCollection );
@@ -468,7 +562,7 @@ class StandardActionManager::Private
           collection.setContentMimeTypes( mts );
       }
       CollectionCreateJob *job = new CollectionCreateJob( collection );
-      q->connect( job, SIGNAL( result( KJob* ) ), q, SLOT( collectionCreationResult( KJob* ) ) );
+      q->connect( job, SIGNAL(result(KJob*)), q, SLOT(collectionCreationResult(KJob*)) );
     }
 
     void slotCopyCollections()
@@ -516,7 +610,110 @@ class StandardActionManager::Private
 
       foreach ( const Collection &collection, collections ) {
         CollectionDeleteJob *job = new CollectionDeleteJob( collection, q );
-        q->connect( job, SIGNAL( result( KJob* ) ), q, SLOT( collectionDeletionResult( KJob* ) ) );
+        q->connect( job, SIGNAL(result(KJob*)), q, SLOT(collectionDeletionResult(KJob*)) );
+      }
+    }
+
+    void slotMoveCollectionToTrash()
+    {
+      const Collection::List collections = selectedCollections();
+      if ( collections.isEmpty() )
+        return;
+
+      foreach ( const Collection &collection, collections ) {
+        TrashJob *job = new TrashJob( collection, q );
+        q->connect( job, SIGNAL(result(KJob*)), q, SLOT(moveCollectionToTrashResult(KJob*)) );
+      }
+    }
+
+    void slotRestoreCollectionFromTrash()
+    {
+      const Collection::List collections = selectedCollections();
+      if ( collections.isEmpty() )
+        return;
+
+      foreach ( const Collection &collection, collections ) {
+        TrashRestoreJob *job = new TrashRestoreJob( collection, q );
+        q->connect( job, SIGNAL(result(KJob*)), q, SLOT(moveCollectionToTrashResult(KJob*)) );
+      }
+    }
+
+    Item::List selectedItems() const
+    {
+      Item::List items;
+
+      Q_ASSERT( itemSelectionModel );
+
+      foreach ( const QModelIndex &index, itemSelectionModel->selectedRows() ) {
+        Q_ASSERT( index.isValid() );
+        const Item item = index.data( ItemModel::ItemRole ).value<Item>();
+        Q_ASSERT( item.isValid() );
+
+        items << item;
+      }
+
+      return items;
+    }
+
+    void slotMoveItemToTrash()
+    {
+      const Item::List items = selectedItems();
+      if ( items.isEmpty() )
+        return;
+
+      TrashJob *job = new TrashJob( items, q );
+      q->connect( job, SIGNAL(result(KJob*)), q, SLOT(moveItemToTrashResult(KJob*)) );
+    }
+
+    void slotRestoreItemFromTrash()
+    {
+      const Item::List items = selectedItems();
+      if ( items.isEmpty() )
+        return;
+
+      TrashRestoreJob *job = new TrashRestoreJob( items, q );
+      q->connect( job, SIGNAL(result(KJob*)), q, SLOT(moveItemToTrashResult(KJob*)) );
+    }
+
+    void slotTrashRestoreCollection()
+    {
+      const Collection::List collections = selectedCollections();
+      if ( collections.isEmpty() )
+        return;
+
+      bool collectionsAreInTrash = false;
+      foreach ( const Collection &collection, collections ) {
+        if ( collection.hasAttribute<EntityDeletedAttribute>() ) {
+          collectionsAreInTrash = true;
+          break;
+        }
+      }
+
+      if (collectionsAreInTrash) {
+        slotRestoreCollectionFromTrash();
+      } else {
+        slotMoveCollectionToTrash();
+      }
+    }
+
+    void slotTrashRestoreItem()
+    {
+      const Item::List items = selectedItems();
+      if ( items.isEmpty() )
+        return;
+
+      bool itemsAreInTrash = false;
+      foreach ( const Item &item, items ) {
+        if ( item.hasAttribute<EntityDeletedAttribute>() ) {
+          itemsAreInTrash = true;
+          break;
+        }
+      }
+
+      if (itemsAreInTrash) {
+        slotRestoreItemFromTrash();
+      } else {
+        slotMoveItemToTrash();
       }
     }
 
@@ -531,7 +728,7 @@ class StandardActionManager::Private
       if ( collections.isEmpty() )
         return;
 
-      foreach( Collection collection, collections ) {
+      foreach( const Collection &collection, collections ) {
         AgentManager::self()->synchronizeCollection( collection, false );
       }
     }
@@ -547,7 +744,7 @@ class StandardActionManager::Private
       if ( collections.isEmpty() )
         return;
 
-      foreach( Collection collection, collections ) {
+      foreach( const Collection &collection, collections ) {
         AgentManager::self()->synchronizeCollection( collection, true );
       }
     }
@@ -635,7 +832,7 @@ class StandardActionManager::Private
         return;
 
       ItemDeleteJob *job = new ItemDeleteJob( items, q );
-      q->connect( job, SIGNAL( result( KJob* ) ), q, SLOT( itemDeletionResult( KJob* ) ) );
+      q->connect( job, SIGNAL(result(KJob*)), q, SLOT(itemDeletionResult(KJob*)) );
     }
 
     void slotLocalSubscription()
@@ -689,20 +886,30 @@ class StandardActionManager::Private
       const QModelIndexList list = collectionSelectionModel->selectedRows();
       if ( list.isEmpty() )
         return;
-
       const QModelIndex index = list.first();
       Q_ASSERT( index.isValid() );
       const Collection collection = index.data( CollectionModel::CollectionRole ).value<Collection>();
       Q_ASSERT( collection.isValid() );
 
-      bool ok;
-      const QString label = KInputDialog::getText( contextText( StandardActionManager::RenameFavoriteCollection, StandardActionManager::DialogTitle ),
-                                                   contextText( StandardActionManager::RenameFavoriteCollection, StandardActionManager::DialogText ),
-                                                   favoritesModel->favoriteLabel( collection ), &ok, parentWidget );
-      if ( !ok )
-        return;
+      const QString displayName = collection.hasAttribute<EntityDisplayAttribute>() ? collection.attribute<EntityDisplayAttribute>()->displayName() : collection.name();
 
-      favoritesModel->setFavoriteLabel( collection, label );
+      RenameFavoriteDialog dlg(contextText( StandardActionManager::RenameFavoriteCollection, StandardActionManager::DialogTitle ),contextText( StandardActionManager::RenameFavoriteCollection, StandardActionManager::DialogText ) , favoritesModel->favoriteLabel( collection ), displayName, parentWidget );
+      if ( dlg.exec() )
+      {
+        favoritesModel->setFavoriteLabel( collection, dlg.newName() );
+      }
+    }
+
+    void slotSynchronizeFavoriteCollections()
+    {
+      Q_ASSERT( favoritesModel );
+      foreach( const Collection& collection, favoritesModel->collections() ) {
+        // there might be virtual collections in favorites which cannot be checked
+        // so let's be safe here, agentmanager asserts otherwise
+        if ( !collection.resource().isEmpty() ) {
+          AgentManager::self()->synchronizeCollection( collection, false );
+        }
+      }
     }
 
     void slotCopyCollectionTo()
@@ -793,7 +1000,7 @@ class StandardActionManager::Private
 
         if ( agentType.isValid() ) {
           AgentInstanceCreateJob *job = new AgentInstanceCreateJob( agentType, q );
-          q->connect( job, SIGNAL( result( KJob* ) ), SLOT( resourceCreationResult( KJob* ) ) );
+          q->connect( job, SIGNAL(result(KJob*)), SLOT(resourceCreationResult(KJob*)) );
           job->configure( parentWidget );
           job->start();
         }
@@ -823,8 +1030,9 @@ class StandardActionManager::Private
       if ( instances.isEmpty() )
         return;
 
-      foreach ( AgentInstance instance, instances )
+      foreach ( AgentInstance instance, instances ) { //krazy:exclude=foreach
         instance.synchronize();
+      }
     }
 
     void slotResourceProperties()
@@ -841,7 +1049,7 @@ class StandardActionManager::Private
       setWorkOffline( offline );
 
       AgentInstance::List instances = AgentManager::self()->instances();
-      foreach ( AgentInstance instance, instances ) {
+      foreach ( AgentInstance instance, instances ) { //krazy:exclude=foreach
         instance.setIsOnline( !offline );
       }
     }
@@ -881,13 +1089,25 @@ class StandardActionManager::Private
       const QMimeData *mimeData = selectionModel->model()->mimeData( selectionModel->selectedRows() );
 
       const QModelIndex index = action->data().value<QModelIndex>();
-
       Q_ASSERT( index.isValid() );
 
       QAbstractItemModel *model = const_cast<QAbstractItemModel *>( index.model() );
+      const Collection collection = index.data( EntityTreeModel::CollectionRole ).value<Collection>();
+      addRecentCollection( collection.id() );
       model->dropMimeData( mimeData, dropAction, -1, -1, index );
     }
 
+    void addRecentCollection( Akonadi::Collection::Id id )
+    {
+      QMapIterator<StandardActionManager::Type, QWeakPointer<RecentCollectionAction> > item(mRecentCollectionsMenu);
+      while (item.hasNext()) {
+        item.next();
+        if ( item.value().data() ) {
+          item.value().data()->addRecentCollection( id );
+        }
+      }
+    }
+
     void collectionCreationResult( KJob *job )
     {
       if ( job->error() ) {
@@ -906,6 +1126,24 @@ class StandardActionManager::Private
       }
     }
 
+    void moveCollectionToTrashResult( KJob *job )
+    {
+      if ( job->error() ) {
+        KMessageBox::error( parentWidget,
+                            contextText( StandardActionManager::MoveCollectionsToTrash, StandardActionManager::ErrorMessageText ).arg( job->errorString() ),
+                            contextText( StandardActionManager::MoveCollectionsToTrash, StandardActionManager::ErrorMessageTitle ) );
+      }
+    }
+
+    void moveItemToTrashResult( KJob *job )
+    {
+      if ( job->error() ) {
+        KMessageBox::error( parentWidget,
+                            contextText( StandardActionManager::MoveItemsToTrash, StandardActionManager::ErrorMessageText ).arg( job->errorString() ),
+                            contextText( StandardActionManager::MoveItemsToTrash, StandardActionManager::ErrorMessageTitle ) );
+      }
+    }
+
     void itemDeletionResult( KJob *job )
     {
       if ( job->error() ) {
@@ -1146,6 +1384,7 @@ class StandardActionManager::Private
     QStringList mMimeTypeFilter;
     QStringList mCapabilityFilter;
     QStringList mCollectionPropertiesPageNames;
+    QMap<StandardActionManager::Type, QWeakPointer<RecentCollectionAction> > mRecentCollectionsMenu;
 };
 
 //@endcond
@@ -1159,7 +1398,7 @@ StandardActionManager::StandardActionManager( KActionCollection * actionCollecti
   d->actionCollection = actionCollection;
   d->mActionStateManager.setReceiver( this );
 #ifndef QT_NO_CLIPBOARD
-  connect( QApplication::clipboard(), SIGNAL( changed( QClipboard::Mode ) ), SLOT( clipboardChanged( QClipboard::Mode ) ) );
+  connect( QApplication::clipboard(), SIGNAL(changed(QClipboard::Mode)), SLOT(clipboardChanged(QClipboard::Mode)) );
 #endif
 }
 
@@ -1171,8 +1410,8 @@ StandardActionManager::~ StandardActionManager()
 void StandardActionManager::setCollectionSelectionModel( QItemSelectionModel * selectionModel )
 {
   d->collectionSelectionModel = selectionModel;
-  connect( selectionModel, SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
-           SLOT( collectionSelectionChanged() ) );
+  connect( selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+           SLOT(collectionSelectionChanged()) );
 
   d->checkModelsConsistency();
 }
@@ -1180,8 +1419,8 @@ void StandardActionManager::setCollectionSelectionModel( QItemSelectionModel * s
 void StandardActionManager::setItemSelectionModel( QItemSelectionModel * selectionModel )
 {
   d->itemSelectionModel = selectionModel;
-  connect( selectionModel, SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
-           SLOT( updateActions() ) );
+  connect( selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+           SLOT(updateActions()) );
 }
 
 void StandardActionManager::setFavoriteCollectionsModel( FavoriteCollectionsModel *favoritesModel )
@@ -1193,22 +1432,29 @@ void StandardActionManager::setFavoriteCollectionsModel( FavoriteCollectionsMode
 void StandardActionManager::setFavoriteSelectionModel( QItemSelectionModel *selectionModel )
 {
   d->favoriteSelectionModel = selectionModel;
-  connect( selectionModel, SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
-           SLOT( favoriteSelectionChanged() ) );
+  connect( selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+           SLOT(favoriteSelectionChanged()) );
   d->checkModelsConsistency();
 }
 
 KAction* StandardActionManager::createAction( Type type )
 {
   Q_ASSERT( type < LastType );
-  Q_ASSERT( standardActionData[type].name );
   if ( d->actions[type] )
     return d->actions[type];
   KAction *action = 0;
   switch ( standardActionData[type].actionType ) {
     case NormalAction:
+    case ActionWithAlternative:
       action = new KAction( d->parentWidget );
       break;
+    case ActionAlternative:
+      d->actions[type] = d->actions[type-1];
+      Q_ASSERT( d->actions[type] );
+      if ( (LastType > type+1) && (standardActionData[type+1].actionType == ActionAlternative) ) {
+        createAction(static_cast<Type>(type+1)); //ensure that alternative actions are initialized when not created by createAllActions
+      }
+      return d->actions[type];
     case MenuAction:
       action = new KActionMenu( d->parentWidget );
       break;
@@ -1235,33 +1481,40 @@ KAction* StandardActionManager::createAction( Type type )
   if ( standardActionData[type].slot ) {
     switch ( standardActionData[type].actionType ) {
       case NormalAction:
-        connect( action, SIGNAL( triggered() ), standardActionData[type].slot );
+      case ActionWithAlternative:
+        connect( action, SIGNAL(triggered()), standardActionData[type].slot );
         break;
       case MenuAction:
         {
           KActionMenu *actionMenu = qobject_cast<KActionMenu*>( action );
-          connect( actionMenu->menu(), SIGNAL( triggered( QAction* ) ), standardActionData[type].slot );
+          connect( actionMenu->menu(), SIGNAL(triggered(QAction*)), standardActionData[type].slot );
         }
         break;
       case ToggleAction:
         {
-          connect( action, SIGNAL( triggered( bool ) ), standardActionData[type].slot );
+          connect( action, SIGNAL(triggered(bool)), standardActionData[type].slot );
         }
         break;
+      case ActionAlternative:
+        Q_ASSERT(0);
     }
   }
 
   if ( type == ToggleWorkOffline ) {
     // inititalize the action state with information from config file
-    disconnect( action, SIGNAL( triggered( bool ) ), this, standardActionData[type].slot );
+    disconnect( action, SIGNAL(triggered(bool)), this, standardActionData[type].slot );
     action->setChecked( workOffline() );
-    connect( action, SIGNAL( triggered( bool ) ), this, standardActionData[type].slot );
+    connect( action, SIGNAL(triggered(bool)), this, standardActionData[type].slot );
 
     //TODO: find a way to check for updates to the config file
   }
 
+  Q_ASSERT( standardActionData[type].name );
   d->actionCollection->addAction( QString::fromLatin1(standardActionData[type].name), action );
   d->actions[type] = action;
+  if ( ( standardActionData[type].actionType == ActionWithAlternative ) &&  (standardActionData[type+1].actionType == ActionAlternative)) {
+    createAction(static_cast<Type>(type+1)); //ensure that alternative actions are initialized when not created by createAllActions
+  }
   d->updateActions();
   return action;
 }
@@ -1295,9 +1548,9 @@ void StandardActionManager::interceptAction( Type type, bool intercept )
     return;
 
   if ( intercept )
-    disconnect( action, SIGNAL( triggered() ), this, standardActionData[type].slot );
+    disconnect( action, SIGNAL(triggered()), this, standardActionData[type].slot );
   else
-    connect( action, SIGNAL( triggered() ), standardActionData[type].slot );
+    connect( action, SIGNAL(triggered()), standardActionData[type].slot );
 }
 
 Akonadi::Collection::List StandardActionManager::selectedCollections() const
@@ -1357,4 +1610,11 @@ void StandardActionManager::setCollectionPropertiesPageNames( const QStringList
   d->mCollectionPropertiesPageNames = names;
 }
 
+void StandardActionManager::createActionFolderMenu(QMenu *menu, Type type)
+{
+  d->createActionFolderMenu( menu, type );
+}
+
+
+
 #include "standardactionmanager.moc"
