@@ -34,6 +34,7 @@
 
 #include "incidencebase.h"
 #include "calformat.h"
+#include "incidenceformatter.h"
 
 #include <kglobal.h>
 #include <klocale.h>
@@ -100,7 +101,7 @@ void IncidenceBase::Private::init( const Private &other )
 
   mAttendees.clearAll();
   Attendee::List::ConstIterator it;
-  for ( it = other.mAttendees.begin(); it != other.mAttendees.end(); ++it ) {
+  for ( it = other.mAttendees.constBegin(); it != other.mAttendees.constEnd(); ++it ) {
     mAttendees.append( new Attendee( *(*it) ) );
   }
 }
@@ -128,6 +129,11 @@ IncidenceBase::~IncidenceBase()
 
 IncidenceBase &IncidenceBase::operator=( const IncidenceBase &other )
 {
+  // check for self assignment
+  if ( &other == this ) {
+    return *this;
+  }
+
   CustomProperties::operator=( other );
   d->init( *other.d );
   mReadOnly = other.mReadOnly;
@@ -211,7 +217,7 @@ void IncidenceBase::setOrganizer( const Person &o )
 void IncidenceBase::setOrganizer( const QString &o )
 {
   QString mail( o );
-  if ( mail.startsWith( "MAILTO:", Qt::CaseInsensitive ) ) {
+  if ( mail.startsWith( QLatin1String( "MAILTO:" ), Qt::CaseInsensitive ) ) {
     mail = mail.remove( 0, 7 );
   }
 
@@ -252,8 +258,8 @@ QString IncidenceBase::dtStartTimeStr( bool shortfmt, const KDateTime::Spec &spe
       timeZone = ' ' + spec.timeZone().name();
     }
 
-    return KGlobal::locale()->formatTime( dtStart().toTimeSpec( spec ).time(), !shortfmt )
-      + timeZone;
+    return KGlobal::locale()->formatTime(
+      dtStart().toTimeSpec( spec ).time(), !shortfmt ) + timeZone;
   } else {
     return KGlobal::locale()->formatTime( dtStart().time(), !shortfmt );
   }
@@ -269,8 +275,8 @@ QString IncidenceBase::dtStartDateStr( bool shortfmt, const KDateTime::Spec &spe
     }
 
     return KGlobal::locale()->formatDate(
-      dtStart().toTimeSpec( spec ).date(), ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) )
-      + timeZone;
+      dtStart().toTimeSpec( spec ).date(),
+      ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) ) + timeZone;
   } else {
     return KGlobal::locale()->formatDate(
       dtStart().date(), ( shortfmt ? KLocale::ShortDate : KLocale::LongDate ) );
@@ -280,7 +286,7 @@ QString IncidenceBase::dtStartDateStr( bool shortfmt, const KDateTime::Spec &spe
 QString IncidenceBase::dtStartStr( bool shortfmt, const KDateTime::Spec &spec ) const
 {
   if ( allDay() ) {
-    return dtStartDateStr( shortfmt, spec );
+    return IncidenceFormatter::dateToString( dtStart(), shortfmt, spec );
   }
 
   if ( spec.isValid() ) {
@@ -471,7 +477,9 @@ void IncidenceBase::updated()
     d->mUpdatedPending = true;
   } else {
     foreach ( IncidenceObserver *o, d->mObservers ) {
-      o->incidenceUpdated( this );
+      if ( o ) {
+        o->incidenceUpdated( this );
+      }
     }
   }
 }
