@@ -362,13 +362,15 @@ void ICalTimeZone::virtual_hook( int id, void *data )
 class ICalTimeZoneDataPrivate
 {
   public:
-    ICalTimeZoneDataPrivate() : icalComponent(0) {}
+    ICalTimeZoneDataPrivate() : icalComponent( 0 ) {}
+
     ~ICalTimeZoneDataPrivate()
     {
       if ( icalComponent ) {
         icalcomponent_free( icalComponent );
       }
     }
+
     icalcomponent *component() const { return icalComponent; }
     void setComponent( icalcomponent *c )
     {
@@ -377,9 +379,11 @@ class ICalTimeZoneDataPrivate
       }
       icalComponent = c;
     }
+
     QString       location;       // name of city for this time zone
     QByteArray    url;            // URL of published VTIMEZONE definition (optional)
     QDateTime     lastModified;   // time of last modification of the VTIMEZONE component (optional)
+
   private:
     icalcomponent *icalComponent; // ical component representing this time zone
 };
@@ -401,15 +405,17 @@ ICalTimeZoneData::ICalTimeZoneData( const ICalTimeZoneData &rhs )
 }
 
 #ifdef Q_OS_WINCE
-// Helper function to convert Windows reccurencies to a QDate
+// Helper function to convert Windows recurrences to a QDate
 static QDate find_nth_weekday_in_month_of_year( int nth, int dayOfWeek, int month, int year ) {
-    const QDate first( year, month, 1 );
-    const int actualDayOfWeek = first.dayOfWeek();
-    QDate candidate = first.addDays( ( nth - 1 ) * 7 + dayOfWeek - actualDayOfWeek );
-    if ( nth == 5 )
-        if ( candidate.month() != month )
-            candidate = candidate.addDays( -7 );
-    return candidate;
+  const QDate first( year, month, 1 );
+  const int actualDayOfWeek = first.dayOfWeek();
+  QDate candidate = first.addDays( ( nth - 1 ) * 7 + dayOfWeek - actualDayOfWeek );
+  if ( nth == 5 ) {
+    if ( candidate.month() != month ) {
+      candidate = candidate.addDays( -7 );
+    }
+  }
+  return candidate;
 }
 #endif // Q_OS_WINCE
 
@@ -435,10 +441,12 @@ ICalTimeZoneData::ICalTimeZoneData( const KTimeZoneData &rhs,
       if ( ktz.data(true) ) {
         ICalTimeZone icaltz( ktz, earliest );
         icaltimezone *itz = icaltz.icalTimezone();
+        if (itz) {
         c = icalcomponent_new_clone( icaltimezone_get_component( itz ) );
         icaltimezone_free( itz, 1 );
       }
     }
+    }
     if ( !c ) {
       // Try to fetch a built-in libical time zone.
       icaltimezone *itz = icaltimezone_get_builtin_timezone( tz.name().toUtf8() );
@@ -486,7 +494,7 @@ ICalTimeZoneData::ICalTimeZoneData( const KTimeZoneData &rhs,
       // In that case try get one transition to write a valid VTIMEZONE entry.
 #ifdef Q_OS_WINCE
       TIME_ZONE_INFORMATION currentTimeZone;
-      GetTimeZoneInformation(&currentTimeZone);
+      GetTimeZoneInformation( &currentTimeZone );
       if ( QString::fromWCharArray( currentTimeZone.StandardName ) != tz.name() ) {
         kDebug() << "VTIMEZONE entry will be invalid for: " << tz.name();
       } else {
@@ -503,17 +511,19 @@ ICalTimeZoneData::ICalTimeZoneData( const KTimeZoneData &rhs,
         // Generate the transitions from the minimal to the maximal year that the calendar
         // offers on WinCE
         for ( int i = 2000; i <= 2050; i++ ) {
-          QDateTime standardTime = QDateTime(  find_nth_weekday_in_month_of_year( std.wDay,
-                                                 std.wDayOfWeek ? std.wDayOfWeek : 7,
-                                                 std.wMonth, i ) ,
-                                               QTime( std.wHour, std.wMinute,
-                                                 std.wSecond, std.wMilliseconds ) );
+          QDateTime standardTime = QDateTime( find_nth_weekday_in_month_of_year(
+                                                std.wDay,
+                                                std.wDayOfWeek ? std.wDayOfWeek : 7,
+                                                std.wMonth, i ),
+                                              QTime( std.wHour, std.wMinute,
+                                                     std.wSecond, std.wMilliseconds ) );
 
-          QDateTime daylightTime = QDateTime(  find_nth_weekday_in_month_of_year( dlt.wDay,
-                                                 dlt.wDayOfWeek ? dlt.wDayOfWeek : 7,
-                                                 dlt.wMonth, i ) ,
-                                               QTime( dlt.wHour, dlt.wMinute,
-                                                 dlt.wSecond, dlt.wMilliseconds ) );
+          QDateTime daylightTime = QDateTime( find_nth_weekday_in_month_of_year(
+                                                dlt.wDay,
+                                                dlt.wDayOfWeek ? dlt.wDayOfWeek : 7,
+                                                dlt.wMonth, i ),
+                                              QTime( dlt.wHour, dlt.wMinute,
+                                                     dlt.wSecond, dlt.wMilliseconds ) );
 
           transits << KTimeZone::Transition( standardTime, standardPhase )
                    << KTimeZone::Transition( daylightTime, daylightPhase );
@@ -1063,7 +1073,7 @@ ICalTimeZone ICalTimeZoneSource::parse( MSTimeZone *tz )
                                   "Microsoft TIME_ZONE_INFORMATION" );
   phases += daylightPhase;
 
-  int prevOffset = 0;
+  int prevOffset = tz->Bias * -60;
   kdata.setPhases( phases, prevOffset );
 
   // Create transitions
