@@ -52,6 +52,8 @@ SessionThread::~SessionThread()
   if ( !wait( 10 * 1000 ) ) {
     kWarning() << "Session thread refuses to die, killing harder...";
     terminate();
+    // Make sure to wait until it's done, otherwise it can crash when the pthread callback is called
+    wait();
   }
 }
 
@@ -60,7 +62,7 @@ void SessionThread::sendData( const QByteArray &payload )
   QMutexLocker locker(&m_mutex);
 
   m_dataQueue.enqueue( payload );
-  QTimer::singleShot( 0, this, SLOT( writeDataQueue() ) );
+  QTimer::singleShot( 0, this, SLOT(writeDataQueue()) );
 }
 
 void SessionThread::writeDataQueue()
@@ -117,14 +119,14 @@ void SessionThread::readMessage()
   }
 
   if ( m_stream->availableDataSize()>1 ) {
-    QTimer::singleShot( 0, this, SLOT( readMessage() ) );
+    QTimer::singleShot( 0, this, SLOT(readMessage()) );
   }
 
 }
 
 void SessionThread::closeSocket()
 {
-  QTimer::singleShot( 0, this, SLOT( doCloseSocket() ) );
+  QTimer::singleShot( 0, this, SLOT(doCloseSocket()) );
 }
 
 void SessionThread::doCloseSocket()
@@ -160,12 +162,19 @@ void SessionThread::run()
            m_session, SLOT(socketConnected()) );
   connect( m_socket, SIGNAL(error(KTcpSocket::Error)),
            m_session, SLOT(socketError()) );
-
+  connect( m_socket, SIGNAL(bytesWritten(qint64)),
+           m_session, SLOT(socketActivity()) );
+  if ( m_socket->metaObject()->indexOfSignal("encryptedBytesWritten(qint64)" ) > -1 ) {
+      connect( m_socket, SIGNAL(encryptedBytesWritten(qint64)), // needs kdelibs > 4.8
+               m_session, SLOT(socketActivity()) );
+  }
+  connect( m_socket, SIGNAL(readyRead()),
+           m_session, SLOT(socketActivity()) );
 
   connect( this, SIGNAL(responseReceived(KIMAP::Message)),
            m_session, SLOT(responseReceived(KIMAP::Message)) );
 
-  QTimer::singleShot( 0, this, SLOT( reconnect() ) );
+  QTimer::singleShot( 0, this, SLOT(reconnect()) );
   exec();
 
   delete m_stream;
